internal

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2023 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// ApplicationName is the non-capitalized name of the application (do not change this)
	ApplicationName = "quill"
)

Variables

This section is empty.

Functions

func IsPipedInput

func IsPipedInput() (bool, error)

IsPipedInput returns true if there is no input device, which means the user **may** be providing input via a pipe.

Types

This section is empty.

Directories

Path Synopsis
Package bus provides access to a singleton instance of an event bus (provided by the calling application).
Package bus provides access to a singleton instance of an event bus (provided by the calling application).
Package log contains the singleton object and helper functions for facilitating logging within the library.
Package log contains the singleton object and helper functions for facilitating logging within the library.
ui
tui
Package version contains all build time metadata (version, build time, git commit, etc).
Package version contains all build time metadata (version, build time, git commit, etc).

Jump to