Affected by GO-2026-4671
and 2 other vulnerabilities
GO-2026-4671: Quill vulnerable to SSRF via unvalidated URL from Apple notarization log retrieval in github.com/anchore/quill
GO-2026-4672: Quill has DoS via unbounded read of HTTP response body during notarization in github.com/anchore/quill
GO-2026-4675: Quill has unbounded memory allocation via unvalidated size fields in Mach-O binary parsing in github.com/anchore/quill
package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Apr 12, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ExitWithErrorf(format string, args ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.