Documentation
¶
Index ¶
Constants ¶
const (
// ApplicationName is the non-capitalized name of the application (do not change this)
ApplicationName = "quill"
)
Variables ¶
This section is empty.
Functions ¶
func IsPipedInput ¶
IsPipedInput returns true if there is no input device, which means the user **may** be providing input via a pipe.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package bus provides access to a singleton instance of an event bus (provided by the calling application).
|
Package bus provides access to a singleton instance of an event bus (provided by the calling application). |
|
Package log contains the singleton object and helper functions for facilitating logging within the library.
|
Package log contains the singleton object and helper functions for facilitating logging within the library. |
|
Package version contains all build time metadata (version, build time, git commit, etc).
|
Package version contains all build time metadata (version, build time, git commit, etc). |
Click to show internal directories.
Click to hide internal directories.